\name{Wikipedia_stats}
\alias{Wikipedia_stats}
\docType{data}
\title{Wikipedia Statistics Corpus}
\description{
  A corpus with English Wikipedia texts on statistical topics,
  obtained by harvesting the texts in all pages in most subcategories of
  Wikipedia's top-level statistics category 
  (\url{http://en.wikipedia.org/wiki/Category:Statistics}).
}
\usage{
data("Wikipedia_stats")
}
\format{
  A \code{\link[tm:VCorpus]{Corpus}} of plain text documents.
}
\details{
  The corpus was built by using the MediaWiki API 
  (\verb{action=query&list=categorymembers}) to identify and fetch all
  pages in the top-level category \sQuote{Statistics}, and, for the
  category pages thus found, recursively identify and fetch all pages in
  the respective categories, excluding categories which would pull in
  \dQuote{too much} (such as \sQuote{Statistical data sets} or
  \sQuote{Fields of applications of statistics}).  Then for all 
  pages identified, the HTML content is fetched, and XPath is used to
  extract the page \dQuote{texts} as the content inside \verb{<p>} tags.

  The code for doing so is not included in the package: it is planned to
  put the general-purpose parts into a MediaWiki API package eventually.
}
\examples{
data("Wikipedia_stats")
## Extract the page ids (titles).
ids <- unlist(meta(Wikipedia_stats, "ID", type = "local"))
## Find the 10 most frequent terms in the titles:
require("tm")
doc <- PlainTextDocument(paste(ids, collapse = "\n"), language = "en")
tab <- termFreq(doc, control = list(stopwords = TRUE, tokenize = "MC"))
head(sort(tab, decreasing = TRUE), 10)
}
\keyword{datasets}
